GUI User Guide — LaVue 2.76.0 documentation

# GUI User Guide

- A widget with Image Source(s) is in the corner of the main window top left side where a lavue user chooses a detector image source.

- Below it the Range Window and Down-Sampling group allows for selecting a displayed image part and down-sampling it with a given reduction function

- In the Filters group users adds his/her plugins for evaluating images

- the Memory buffer group allows to access previously displayed images

- In the Image preparation group a background and mask image can be selected as well simple image transformation, i.e. flip, transpose.

- In the Intensity display scaling frame the user selects what intensity scaling should be selected to fit the proper colors on the 2D-image display.

- The Display levels and colors widget is used so set minimum and maximum displayed intensity and choose the display color gradient.

- The Image statistics part shows the basic statistic information about the 2D-image.

- On the top right side of the main window the user finds an Image/File name label as well as a button for Load images from a file-system, Reload images from a file -system, this Help, the Configuration and Quit buttons.

- Below them the detector 2D image is displayed with associated 1D-plots.

- At the bottom of the right side the user selects Specialized Image Tools which provide a simple analysis of the detector image.

Table of Contents

- Image Sources and stitching images
  - Hirda
  - HTTP response
  - Tango Attribute
  - Tango Events
  - Tango File
  - DOOCS property
  - ZMQ stream
  - NeXus File
  - Tine Property
  - Epics PV
  - ASAPO
  - Test
- Range Window and Down-Sampling
- LaVue Filters
- Memory Buffer
- Image Preparation
- Scaling and Display Levels
- Image Statistics
- 2D Plot
- Specialized Tools
  - Intensity Tool
  - ROI Tool
  - LineCut Tool
  - Angle/Q Tool
  - MoveMotor Tool
  - MeshScan Tool
  - 1d-Plot Tool
  - Projections Tool
  - Q+ROI+Proj Tool
  - Maxima Tool
  - Parameters Tool
  - Diffractogram Tool
- Images from FileSystem
- Configuration
  - General Settings
  - Layout Settings
  - Hidra/HTTP/ZMQ/ASAPO/NeXus Image Source Settings
  - Tango/DOOCS/Tine/Epics Image Source Settings
  - Filter plugins settings